%******************************************************************
%
%   [b] = crotcay_o(b1,b2)
%
%******************************************************************
%
%   Cayley transform for rotations - composition of rotations
%
%    given vectors b1, b2 corresponding to R1=cay(b1x), R2=cay(b2x)
%    computes the Cayley rotation vector b
%    corresponding to the composed rotation R=R2*R1=cay(bx)
%
%   NB - this is known also as Gibbs/Rodrigues parameterisation
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [b] = crotcay_o(b1,b2)
%
% >>> Composed Cayley rotation vector
%
b = 1/(1 - b2'*b1) * (b2 + b1 + cross_x(b2,b1));