%******************************************************************
%
%   [r] = crotexp_o(r1,r2)
%
%******************************************************************
%
%   Exponential map of rotations - composition of rotations
%
%    given vectors r1, r2 corresponding to R1=exp(r1x), R2=exp(b2x)
%    computes the rotation vector r
%    corresponding to the composed rotation R=R2*R1=exp(rx)
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [r] = crotexp_o(r1,r2)
%
% >>> Ingredients
%
phi1 = norm(r1);
e1 = r1/phi1;
phi2 = norm(r2);
e2 = r2/phi2;
%
c1h = cos(phi1/2);
s1h = sin(phi1/2);
c2h = cos(phi2/2);
s2h = sin(phi2/2);
%
ch = c1h*c2h - s1h*s2h * e2'*e1;
she = c1h*s2h*e2 + c2h*s1h*e1 + s1h*s2h * cross_x(e2,e1);
sh = norm(she);
phi = 2*atan2(sh,ch);
%
% >>> Composed rotation vector
%
r = phi/sh * she;