%******************************************************************
%
%   [q] = crotqua_o(q1,q2)
%
%******************************************************************
%
%   Unit quaternion of rotations - composition of rotations
%
%    given unit quaternions q1=(q10,q1v), q1=(q10,q1v)
%    corresponding to R1, R2,
%    computes the unit quaternion q
%    corresponding to the composed rotation R=R2*R1
%
%   NB - this is known also as Euler-Rodrigues parameterization
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [q] = crotqua_o(q1,q2)
%
% >>> Ingredients
%
I = eye(3);
q10 = q1(1);
q1v = q1(2:4);
if (q10*q10+q1v'*q1v ~= 1)
    disp(' ### function crotqua : error')
end
q20 = q2(1);
q2v = q2(2:4);
q2vx = cross_o(q2v);
if (q20*q20+q2v'*q2v ~= 1)
    disp(' ### function crotqua : error')
end
%
M2l = [ q20 ,     -q2v'  ;
        q2v , q20*I+q2vx ];
%
% >>> Composed rotation unit quaternion
%
q = M2l*q1;