%******************************************************************
%
%   [Ecorot] = dmrotcar_o(phi,theta,psi)
%
%******************************************************************
%
%   Cardan angles ('aeronautical' Euler angles) - associated differential map (2)
%
%    given the Cardan angles (phi,theta,psi),
%    computes the operator Ecorot such that omegacorot=Ecorot*dot(q)
%    where q=[phi;theta;psi]
%
%   NB1 - omegacorot is the 'material' spin
%
%   NB2 - psi   = azimuth angle
%         theta = elevation angle
%         phi   = bank angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [Ecorot] = dmrotcar_o(phi,theta,psi)
%
% Ingredients
%
e1corot = [ 1 ; 0 ; 0 ];
encorot = [ 0 ; cos(phi) ; -sin(phi) ];
i3corot = [ -sin(theta) ; cos(theta)*sin(phi) ; cos(theta)*cos(phi) ];
%
% >>> Rotation associated differential operator (2)
%
Ecorot = [ i3corot , encorot , e1corot ];