%******************************************************************
%
%   [Ecorot] = dmroteul_o(phi,theta,psi)
%
%******************************************************************
%
%   Classical Euler angles - associated differential map (2)
%
%    given the classical Euler angles (phi,theta,psi),
%    computes the operator Ecorot such that omegacorot=Ecorot*dot(q)
%    where q=[phi;theta;psi]
%
%   NB1 - omegacorot is the 'material' spin
%
%   NB2 - psi   = precession angle
%         theta = nutation angle
%         phi   = proper rotation angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [Ecorot] = dmroteul_o(phi,theta,psi)
%
% Ingredients
%
i3corot = [ sin(phi)*sin(theta) ; cos(phi)*sin(theta) ; cos(theta) ];
encorot = [ cos(phi) ; -sin(phi) ; 0 ];
e3corot = [ 0 ; 0 ; 1 ];
%
% >>> Rotation associated differential operator (2)
%
Ecorot = [ i3corot , encorot , e3corot ];