%******************************************************************
%
%   [Gcorot] = dmrotqua_o(q)
%
%******************************************************************
%
%   Unit quaternion of rotations - associated differential operator (2)
%
%    given quaternion q=(q0,qv),
%    computes the associated differential operator Gcorot
%    such that omega4corot=Gcorot*dot(q)
%
%   NB1 - omega4orot is the quaternion 'material' spin
%
%   NB2 - this is known also as Euler-Rodrigues parameterization
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [Gcorot] = dmrotqua_o(q)
%
% >>> Ingredients
%
I = eye(3);
q0 = q(1);
qv = q(2:4);
qvx = cross_o(qv);
if (q0*q0+qv'*qv ~= 1)
    disp(' ### function dmrotqua : error')
end
%
Ml = [ q0 ,    -qv'  ;
       qv , q0*I+qvx ];
%
% >>> Associated differential operator (2)
%
Gcorot = 2*Ml';