%******************************************************************
%
%   [E] = drotcar_o(phi,theta,psi)
%
%******************************************************************
%
%   Cardan angles ('aeronautical' Euler angles) - associated differential map (1)
%
%    given the Cardan angles (phi,theta,psi),
%    computes the operator E such that omega=E*dot(q)
%    where q=[phi;theta;psi]
%
%   NB1 - omega is the 'spatial' spin
%
%   NB2 - psi   = azimuth angle
%         theta = elevation angle
%         phi   = bank angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [E] = drotcar_o(phi,theta,psi)
%
% Ingredients
%
e1 = [ cos(psi)*cos(theta) ; sin(psi)*cos(theta) ; -sin(theta) ];
en = [ -sin(psi) ; cos(psi) ; 0 ];
i3 = [ 0 ; 0 ; 1 ];
%
% >>> Rotation associated differential operator (1)
%
E = [ i3 , en , e1 ];