%******************************************************************
%
%   [E] = droteul_o(phi,theta,psi)
%
%******************************************************************
%
%   Classical Euler angles - associated differential map (1)
%
%    given the classical Euler angles (phi,theta,psi),
%    computes the operator E such that omega=E*dot(q)
%    where q=[phi;theta;psi]
%
%   NB1 - omega is the 'spatial' spin
%
%   NB2 - psi   = precession angle
%         theta = nutation angle
%         phi   = proper rotation angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [E] = droteul_o(phi,theta,psi)
%
% Ingredients
%
e3 = [ sin(psi)*sin(theta) ; -cos(psi)*sin(theta) ; cos(theta) ];
en = [ cos(psi) ; sin(psi) ; 0 ];
i3 = [ 0 ; 0 ; 1 ];
%
% >>> Rotation associated differential operator (1)
%
E = [ i3 , en , e3 ];