%******************************************************************
%
%   [S] = drotexp_o(r)
%
%******************************************************************
%
%   Exponential map of rotations - convolution operator
%
%    given vector r of magnitude phi,
%    computes the rotation associated differential tensor S=dexp(rx)
%
%   NB - the general form of the associated differential map is
%
%           dexp(C) = I + C/2 + C^2/3! + C^3/4! + C^4/5! + ...
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [S] = drotexp_o(r)
%
% >>> Ingredients
%
I = eye(3);
phi2 = r'*r;
phi = sqrt(phi2);
rx = cross_o(r);
%
% >>> Coefficients
%
if phi <= .02,
    %
    % >> Taylor expansion
    %
    S1 = (1 - phi2/12 * (1 - phi2/30 * (1 - phi2/56 * (1 - phi2/90)))) / 2;
    S2 = (1 - phi2/20 * (1 - phi2/42 * (1 - phi2/72 * (1 - phi2/110)))) / 6;
else
    %
    % >>> Finite form
    %
    S1 = (1 - cos(phi)) / phi2;
    S2 = (1 - sin(phi) / phi) / phi2;
end
%
% >>> Rotation associated differential tensor
%
S = I + S1*rx + S2*rx*rx;