%******************************************************************
%
%   [G] = drotqua_o(q)
%
%******************************************************************
%
%   Unit quaternion of rotations - associated differential operator (1)
%
%    given quaternion q=(q0,qv),
%    computes the associated differential operator G
%    such that omega4=G*dot(q)
%
%   NB1 - omega4 is the quaternion 'spatial' spin
%
%   NB2 - this is known also as Euler-Rodrigues parameterization
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [G] = drotqua_o(q)
%
% >>> Ingredients
%
I = eye(3);
q0 = q(1);
qv = q(2:4);
qvx = cross_o(qv);
if (q0*q0+qv'*qv ~= 1)
    disp(' ### function drotqua : error')
end
%
Mr = [ q0 ,    -qv'  ;
       qv , q0*I-qvx ];
%
% >>> Associated differential operator (1)
%
G = 2*Mr';