%******************************************************************
%
%   [invS] = invdrotexp_o(r)
%
%******************************************************************
%
%   Exponential map of rotations - inverse convolution operator
%
%    given vector r of magnitude phi,
%    computes the inverse of rotation associated differential
%    tensor invS=dexp(rx)^(-1)
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [invS] = invdrotexp_o(r)
%
% >>> Ingredients
%
I = eye(3);
phi2 = r'*r;
phi = sqrt(phi2);
rx = cross_o(r);
%
% >>> Coefficient
%
if phi <= .02,
 %
 % >> Taylor expansion 
 %
 sigma = (1 + phi2/60 * (1 + phi2/42 * (1 + phi2/40))) / 12;
else
 %
 % >> Finite form
 %
 sigma = (1 - phi * sin(phi) / (2 * (1 - cos(phi)))) / phi2;
end
%
% >>> Inverse of rotation associated differential tensor
%
invS = I - .5*rx + sigma*rx*rx;