%******************************************************************
%
%   [b] = irotcay_o(R)
%
%******************************************************************
%
%   Cayley transform for rotations - inverse problem
%
%    given rotation tensor R=cay(bx),
%    computes the Cayley rotation vector r
%
%   NB1 - this is known also as Gibbs/Rodrigues parameterisation
%
%   NB2 - the general form of Cayley's transform is
%
%            cay(C) = inv(I - C) * (I + C)
%
%         so that the inverse transform is given by
%
%            invcay(A) = - cay(-A)
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [b] = irotcay_o(R)
%
% >>> Ingredients
%
I = eye(3);
zeta = sqrt((3-trace(R))/(1+trace(R)));
s = axial_o(.5*(R-R'));
e = s/norm(s);
%
% >>> Cayley rotation vector
%
b = zeta*e;