%******************************************************************
%
%   [phi,theta,psi] = irotcar_o(R)
%
%******************************************************************
%
%   Cardan angles ('aeronautical' Euler angles) - inverse map
%
%    given rotation tensor R,
%    computes the Cardan angles (phi,theta,psi)
%
%   NB - psi   = azimuth angle
%        theta = elevation angle
%        phi   = bank angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [phi,theta,psi] = irotcar_o(R)
%
% >>> Ingredients
%
i3 = [ 0 ; 0 ; 1 ];
e1 = R(:,1);
nv = cross_x(i3,e1);
nm = norm(nv);
if (nm == 0)
    display(' ### function irotcar_o : error')
    nm == 1;
end
%
% > Nodal unit vector
%
en = nv/nm;
encorot = R'*en;
%
% >>> Euler angles
%
psi   = atan2(-en(1),en(2));
theta = asin(-R(3,1));
phi   = atan2(-encorot(3),encorot(2));