%******************************************************************
%
%   [phi,theta,psi] = iroteul_o(R)
%
%******************************************************************
%
%   Classical Euler angles - inverse map
%
%    given rotation tensor R,
%    computes the classical Euler angles (phi,theta,psi)
%
%   NB - psi   = precession angle
%        theta = nutation angle
%        phi   = proper rotation angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [phi,theta,psi] = iroteul_o(R)
%
% >>> Ingredients
%
i3 = [ 0 ; 0 ; 1 ];
e3 = R(:,3);
%%% i3corot = R(3,:);
%
%%% nv = cross_x(i3corot,e3);
nv = cross_x(i3,e3);
nm = norm(nv);
if (nm == 0)
    display(' ### function iroteul_o : error')
    nm == 1;
end
%
% > Nodal unit vector
%
en = nv/nm;
encorot = R'*en;
%
% >>> Euler angles
%
psi   = atan2(en(2),en(1));
%psi   = atan2(-R(1,3),R(2,3));
theta = acos(R(3,3));
phi   = atan2(-encorot(2),encorot(1));
%phi   = atan2(R(3,1),R(3,2));