%******************************************************************
%
%   [r] = irotexp_o(R)
%
%******************************************************************
%
%   Exponential map of rotations - inverse problem
%
%    given rotation tensor R=exp(rx),
%    computes the rotation vector r
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [r] = irotexp_o(R)
%
% >   Cosine of rotation angle
%
cosphi = .5 * (trace(R) - 1);
%
if cosphi > 0,
    %
    % > Axial vector of R
    %
    s = [ .5*(R(3,2)-R(2,3));
          .5*(R(1,3)-R(3,1));
          .5*(R(2,1)-R(1,2)) ];
    %
    sinphi = sqrt(s'*s);
    phi = atan2(sinphi,cosphi);
    %
    % >>> Rotation vector
    %
    if phi <= 0.02,
        phi2 = phi*phi;
        r = (1/(1-phi2/6*(1-phi2/20)))*s;
    else
        r = (phi/sinphi)*s;
    end
else
    I  = eye(3);
    eet = (.5*(R+R')-I*cosphi)/(1-cosphi);
    [e2,maxcol] = max(diag(eet));
    sqrte = sqrt(e2);
    %
    % > Rotation axis unit vector
    %
    e = eet(:,maxcol)./sqrte;
    %
    evec = [  0   -e(3)  e(2);
             e(3)   0   -e(1);
            -e(2)  e(1)   0  ];
    sinphi = -.5*trace(evec*R);
    phi = atan2(sinphi,cosphi);
    %
    % >>> Rotation vector
    %
    r = phi*e;
end
