%******************************************************************
%
%   [q] = irotqua_o(R)
%
%******************************************************************
%
%   Unit quaternion of rotations - inverse map
%
%    given rotation tensor R,
%    computes the quaternion q=(q0,qv) such that R=Ml(q)*Mr(q)'
%
%   NB - this is known also as Euler-Rodrigues parameterization
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [q] = irotqua_o(R)
%
% >>> Ingredients
%
I = eye(3);
%
Q = .25 * [  1+trace(R)  ,     2*axial_o(R)'   ;
            2*axial_o(R) , (1-trace(R))*I+R+R' ];
[q2,maxcol] = max(diag(Q));
sqrtq = sqrt(q2);
%
% >>> Rotation unit quaternion
%
q = Q(:,maxcol)./sqrtq;