%******************************************************************
%
%   [R] = rotcar_o(phi,theta,psi)
%
%******************************************************************
%
%   Cardan angles ('aeronautical' Euler angles) - direct map
%
%    given the Cardan angles (phi,theta,psi),
%    computes the rotation tensor R=rot(psi,i3)*rot(theta,i2)*rot(phi,i1)
%
%   NB - psi   = azimuth angle
%        theta = elevation angle
%        phi   = bank angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [R] = rotcar_o(phi,theta,psi)
%
% >>> Ingredients
%
R1 = [ 1    0         0     ;
       0 sin(phi)  cos(phi) ;
       0 cos(phi) -sin(phi) ];
R2 = [ cos(theta) 0 sin(theta) ;
           0      1      0     ;
      -sin(theta) 0 cos(theta) ];
R3 = [ cos(psi)  -sin(psi)  0 ;
       sin(psi)   cos(psi)  0 ;
          0          0      1 ];
%
% >>> Rotation tensor
%
R = R3 * R2 * R1;