%******************************************************************
%
%   [R] = rotcay_o(b)
%
%******************************************************************
%
%   Cayley transform for rotations - direct map
%
%    given vector b of magnitude tan(phi/2),
%    computes the rotation tensor R=cay(bx)
%
%   NB1 - this is known also as Gibbs/Rodrigues parameterisation
%
%   NB2 - the general form of Cayley's transform is
%
%            cay(C) = inv(I - C) * (I + C)
%
%        (see ROTLIB function 'cayley_o')
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [R] = rotcay_o(b)
%
% >>> Ingredients
%
I = eye(3);
zeta = norm(b);
bx = cross_o(b);
%
% >>> Rotation tensor
%
R = I + 2/(1 + zeta^2)*(I + bx)*bx;