%******************************************************************
%
%   [R] = roteul_o(phi,theta,psi)
%
%******************************************************************
%
%   Classical Euler angles - direct map
%
%    given the classical Euler angles (phi,theta,psi),
%    computes the rotation tensor R=rot(psi,i3)*rot(theta,i1)*rot(phi,i3)
%
%   NB - psi   = precession angle
%        theta = nutation angle
%        phi   = proper rotation angle
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [R] = roteul_o(phi,theta,psi)
%
% >>> Ingredients
%
Rphi = [ cos(phi) -sin(phi) 0 ;
         sin(phi)  cos(phi) 0 ;
            0         0     1 ];
Rtheta = [ 1      0            0      ;
           0  cos(theta)  -sin(theta) ;
           0  sin(theta)   cos(theta) ];
Rpsi = [ cos(psi)  -sin(psi)  0 ;
         sin(psi)   cos(psi)  0 ;
            0          0      1 ];
%
% >>> Rotation tensor
%
R = Rpsi * Rtheta * Rphi;