%******************************************************************
%
%   [R] = rotqua_o(q)
%
%******************************************************************
%
%   Unit quaternion of rotations - direct map
%
%    given unit quaternion q=[q0;qv],
%    computes the rotation tensor R=Ml(q)*Mr(q)'
%
%   NB - this is known also as Euler-Rodrigues parameterization
%
%******************************************************************
% Lorenzo Trainelli - DIA PoliMi - Nov 2002
%******************************************************************
%
function [R] = rotqua_o(q)
%
% >>> Ingredients
%
I = eye(3);
q0 = q(1);
qv = q(2:4);
qvx = cross_o(qv);
if (q0*q0+qv'*qv ~= 1)
    disp(' ### function rotqua : error')
end
%
Ml = [ q0 ,    -qv'  ;
       qv , q0*I+qvx ];
Mr = [ q0 ,    -qv'  ;
       qv , q0*I-qvx ];
%
bigR = Ml*Mr';
%
% >>> Rotation tensor
%
R = bigR(2:4,2:4);
% R = I + 2*q0*qvx + 2*qvx*qvx; % this is a more direct definition...